from django.urls import path
from .views import HeadshotViewSet, ListPostFeeds, PostReportStatusAPIView, PostViewSet, ReportPostAPIView, ReportReasonListAPIView

urlpatterns = [
    path('profile/posts/create/', PostViewSet.as_view({'post': 'create'}), name='post-create'),
    
    path('profile/<int:user_id>/posts/images/', PostViewSet.as_view({'get': 'list_images'}), name='user-post-images'),
    path('profile/<int:user_id>/posts/videos/', PostViewSet.as_view({'get': 'list_videos'}), name='user-post-videos'),
    
    path('profile/posts/<int:pk>/like/', PostViewSet.as_view({'post': 'like'}), name='post-like'),
    path('profile/posts/<int:pk>/unlike/', PostViewSet.as_view({'delete': 'unlike'}), name='post-unlike'),
    path('profile/posts/<int:pk>/comment/', PostViewSet.as_view({'post': 'comment'}), name='post-comment'),
    path('profile/posts/<int:pk>/comment/<int:comment_id>/', PostViewSet.as_view({'delete': 'delete_comment'}), name='post-delete-comment'),
    
    path('profile/posts/<int:pk>/comments/', PostViewSet.as_view({'get': 'list_comments'}), name='post-list-comments'),
    path('profile/posts/<int:pk>/likes/', PostViewSet.as_view({'get': 'list_likes'}), name='post-list-likes'),
    
    path('profile/posts/<int:pk>/', PostViewSet.as_view({'get': 'retrieve'}), name='post-detail'),
    path('profile/posts/<int:pk>/share/', PostViewSet.as_view({'get': 'share'}), name='post-share'),
    
    path('profile/posts/delete/<int:pk>/', PostViewSet.as_view({'delete': 'delete_post'}), name='delete-post'),
    
    path('profile/headshots/create/', HeadshotViewSet.as_view({'post': 'create'}), name='headshot-create'),
    path('profile/headshots/<int:pk>/', HeadshotViewSet.as_view({'get': 'retrieve'}), name='headshot-detail'),
    path('profile/<int:user_id>/headshots/', HeadshotViewSet.as_view({'get': 'list_user_headshots'}), name='user-headshots'),
    path('profile/list-post-feeds/', ListPostFeeds.as_view(), name='list-post-feeds'),
    path('profile/report_post/', ReportPostAPIView.as_view(), name='report-post'),
    path('profile/report_reasons/', ReportReasonListAPIView.as_view(), name='report-reasons'),
    path('posts/<int:pk>/comments/<int:comment_id>/reply/', PostViewSet.as_view({'post': 'reply_comment'})),
    path('posts/<int:pk>/comments/<int:comment_id>/like/', PostViewSet.as_view({'post': 'like_comment'})),
    path('posts/<int:pk>/comments/<int:comment_id>/replies/', PostViewSet.as_view({'get': 'list_replies'})),
    path('post/<int:post_id>/report-status/', PostReportStatusAPIView.as_view(), name='post-report-status'),
]
